@@ -72,11 +72,6 @@ pref("network.protocol-handler.warn-external.nntp", false);
 pref("network.protocol-handler.warn-external.snews", false);
 pref("network.protocol-handler.warn-external.webcal", false);
 
-// don't warn
-pref("network.protocol-handler.warn-external.rtsp", false);
-pref("network.protocol-handler.warn-external.mms", false);
-pref("network.protocol-handler.warn-external.mmsh", false);
-
 // disable xpinstall
 pref("xpinstall.enabled", false);
 
@@ -127,6 +122,7 @@ pref("general.useragent.locale", "en");
 // pref("extensions.spellcheck.inline.max-misspellings", -1);
 // 0: disabled, 1: only textareas, 2: check textareas and single-line input fields
 pref("layout.spellcheckDefault", 1);
+pref("spellchecker.dictionary", "");
 
 // print settings
 pref("print.print_printer", "PostScript/default");
@@ -142,11 +138,3 @@ pref("dom.storage.enabled", false);
 
 // warn about about:config
 pref("general.warnOnAboutConfig", true);
-
-// Whether delete and backspace should immediately delete characters not
-// visually adjacent to the caret, or adjust the visual position of the caret
-// on the first keypress and delete the character on a second keypress
-// (added in bug https://bugzilla.mozilla.org/show_bug.cgi?id=328834)
-// set to true for parity with gtk entries
-pref("bidi.edit.delete_immediately", true);
-
