@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp 6868 2007-01-28 21:10:37Z jframeau $
+ *  $Id: ContentHandler.cpp,v 1.96 2006/10/15 14:05:38 wbolster Exp $
  */
 
 #include "mozilla-config.h"
@@ -93,18 +93,6 @@ GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
 	/* FIXME: handle aForced / aReason argument in some way? */
 
 	mContext = aContext;
-
-	/* Check for a potential veto */
-	nsCOMPtr<nsIDOMWindow> window (do_GetInterface (aContext));
-	GtkWidget *embed = EphyUtils::FindEmbed (window);
-	if (EPHY_IS_EMBED (embed))
-	{
-		if (g_object_get_data (G_OBJECT (embed), "content-handler-deny"))
-		{
-			return NS_OK;
-		}
-	}
-
 	mLauncher = aLauncher;
 	rv = Init ();
 	NS_ENSURE_SUCCESS (rv, rv);
@@ -377,7 +365,6 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 	{
 		const char *id = gnome_vfs_mime_application_get_desktop_id (mHelperApp);
 
-		/* FIXME! menu editing can make this check fail!!!! */
 		if (id && strcmp (id, "epiphany.desktop") == 0)
 		{
 			mHelperApp = nsnull;
@@ -419,6 +406,8 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	mLauncher->GetMIMEInfo(getter_AddRefs(mimeInfo));
 	NS_ENSURE_TRUE (mimeInfo, NS_ERROR_FAILURE);
 
+	char *info = NULL;
+
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
 		g_return_val_if_fail (mHelperApp, NS_ERROR_FAILURE);
@@ -429,9 +418,15 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 		/* The current time is fine here as the user has just clicked
 		 * a button (it is used as the time for the application opening)
 		 */
-		char *info;
 		info = g_strdup_printf ("gnome-default:%d:%s", gtk_get_current_event_time(), id);
+	}
+	else if (mAction == CONTENT_ACTION_DOWNLOAD)
+	{
+		info = g_strdup_printf ("gnome-browse-to-file:%d", gtk_get_current_event_time());
+	}
 
+	if (info != NULL)
+	{
 		nsString desc;
 		NS_CStringToUTF16 (nsCString (info),
 			           NS_CSTRING_ENCODING_UTF8, desc);
