@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * 
- *  $Id: EphySidebar.h 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: EphySidebar.h,v 1.5 2006/09/16 21:20:36 chpe Exp $
  */
 
 #ifndef EPHY_SIDEBAR_H
@@ -24,6 +24,10 @@
 
 #include <nsISidebar.h>
 
+class nsIComponentManager;
+class nsIFile;
+struct nsModuleComponentInfo;
+
 #define EPHY_SIDEBAR_CLASSNAME \
  "Epiphany's Sidebar Implementation"
 
@@ -38,12 +42,24 @@
 class EphySidebar : public nsISidebar
 {
   public:
-	NS_DECL_ISUPPORTS
-	NS_DECL_NSISIDEBAR
+    NS_DECL_ISUPPORTS
+    NS_DECL_NSISIDEBAR
+
+    EphySidebar();
+
+    static NS_METHOD Register (nsIComponentManager* aComponentManager,
+			       nsIFile* aPath,
+			       const char* aRegistryLocation,
+			       const char* aComponentType,
+			       const nsModuleComponentInfo* aInfo);
+
+    static NS_METHOD Unregister (nsIComponentManager* aComponentManager,
+				 nsIFile* aPath,
+				 const char* aRegistryLocation,
+				 const nsModuleComponentInfo* aInfo);
 
-	EphySidebar();
-	virtual ~EphySidebar();
   private:
+    ~EphySidebar();
 };
 
 #endif /* ! EPHY_SIDEBAR_H */
