@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c 6776 2006-12-31 17:00:59Z chpe $
+ *  $Id: ephy-main.c,v 1.68 2006/09/13 11:34:22 chpe Exp $
  */
 
 #include "config.h"
@@ -427,10 +427,6 @@ main (int argc,
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-	/* Threads have to be initialised before calling ANY glib function */
-	g_thread_init (NULL);
-	dbus_g_thread_init ();
-
 	/* check libxml2 API version epiphany was compiled with against the
 	 * version we're running with.
 	 */
