@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Christophe Fergeau
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2002 Christophe Fergeau
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.92 2006/08/08 10:51:50 jframeau Exp $
+ *  $Id: ephy-notebook.c,v 1.96 2006/11/12 13:26:52 ryanl Exp $
  */
 
 #include "config.h"
@@ -109,7 +109,7 @@ ephy_notebook_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 			{
 				sizeof (EphyNotebookClass),
 				NULL, /* base_init */
@@ -122,7 +122,7 @@ ephy_notebook_get_type (void)
 				(GInstanceInitFunc) ephy_notebook_init
 			};
 
-		static const GInterfaceInfo link_info =
+		const GInterfaceInfo link_info =
 		{
 			NULL,
 			NULL,
@@ -645,12 +645,11 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 			       GTK_RELIEF_NONE);
 	/* don't allow focus on the close button */
 	gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
-	gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
 
 	rcstyle = gtk_rc_style_new ();
 	rcstyle->xthickness = rcstyle->ythickness = 0;
 	gtk_widget_modify_style (close_button, rcstyle);
-	gtk_rc_style_unref (rcstyle),
+	gtk_rc_style_unref (rcstyle);
 
 	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
