@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: window-commands.c,v 1.199 2006/09/24 19:59:37 jframeau Exp $
  */
 
 #include "config.h"
@@ -202,35 +202,6 @@ window_cmd_view_reload (GtkAction *action,
 	ephy_embed_reload (embed, event_with_shift ());
 }
 
-void
-window_cmd_file_new_window (GtkAction *action,
-		            EphyWindow *window)
-{
-	EphyTab *tab;
-
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
-			    EPHY_NEW_TAB_NEW_PAGE |
-			    EPHY_NEW_TAB_IN_NEW_WINDOW);
-}
-
-void
-window_cmd_file_new_tab (GtkAction *action,
-		         EphyWindow *window)
-{
-	EphyTab *tab;
-
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
-			    EPHY_NEW_TAB_NEW_PAGE |
-			    EPHY_NEW_TAB_IN_EXISTING_WINDOW |
-			    EPHY_NEW_TAB_JUMP);
-}
-
 void
 window_cmd_go_bookmarks (GtkAction *action,
 			 EphyWindow *window)
